@@ -8,8 +8,8 @@ from rich.console import Console
 
 import piperider_cli.hack.inquirer as inquirer_hack
 from piperider_cli import datetime_to_str, str_to_datetime, clone_directory, \
-    raise_exception_when_output_directory_not_writable
-from piperider_cli.configuration import PIPERIDER_OUTPUT_PATH, PIPERIDER_COMPARISON_PATH
+    raise_exception_when_directory_not_writable
+from piperider_cli.filesystem import FileSystem
 from piperider_cli.generate_report import setup_report_variables
 
 
@@ -89,6 +89,25 @@ class ComparisonData(object):
         return json.dumps(output)
 
 
+def prepare_default_output_path(comparison_dir: str, created_at):
+    latest_symlink_path = os.path.join(comparison_dir, 'latest')
+    comparison_path = os.path.join(comparison_dir, created_at)
+
+    if not os.path.exists(comparison_path):
+        os.makedirs(comparison_path, exist_ok=True)
+
+    # Create a symlink pointing to the latest comparison directory
+    if os.path.islink(latest_symlink_path):
+        os.unlink(latest_symlink_path)
+    if not os.path.exists(latest_symlink_path):
+        os.symlink(comparison_path, latest_symlink_path)
+    else:
+        console = Console()
+        console.print(f'[bold yellow]Warning: {latest_symlink_path} already exists[/bold yellow]')
+
+    return comparison_path
+
+
 class CompareReport(object):
     def __init__(self, profiler_output_path, a=None, b=None, datasource=None):
         self.profiler_output_path = profiler_output_path
@@ -223,11 +242,13 @@ class CompareReport(object):
         return ComparisonData(self.a.load(), self.b.load())
 
     @staticmethod
-    def exec(*, a=None, b=None, last=None, datasource=None, output=None, debug=False):
+    def exec(*, a=None, b=None, last=None, datasource=None, report_dir=None, output=None, debug=False):
         console = Console()
-        raise_exception_when_output_directory_not_writable(output)
 
-        report = CompareReport(PIPERIDER_OUTPUT_PATH, a, b, datasource=datasource)
+        filesystem = FileSystem(report_dir=report_dir)
+        raise_exception_when_directory_not_writable(output)
+
+        report = CompareReport(filesystem.get_output_dir(), a, b, datasource=datasource)
         if not report.select_reports(use_last_two=last):
             raise Exception('No valid reports found')
         comparison_data = report.generate_data()
@@ -244,18 +265,17 @@ class CompareReport(object):
                 html = setup_report_variables(report_template_html, False, comparison_data.to_json())
                 f.write(html)
 
-            return filename
-
         data_id = comparison_data.id()
-        default_report_directory = os.path.join(PIPERIDER_COMPARISON_PATH, data_id)
-        filename = output_report(default_report_directory)
+        default_report_directory = prepare_default_output_path(filesystem.get_comparison_dir(), data_id)
+        output_report(default_report_directory)
+        report_path = os.path.join(filesystem.get_comparison_dir(), 'latest', 'index.html')
 
         if output:
             clone_directory(default_report_directory, output)
-            filename = os.path.join(output, 'index.html')
+            report_path = os.path.join(output, 'index.html')
 
         console.print()
-        console.print(f"Comparison report: {filename}")
+        console.print(f"Comparison report: {report_path}")
 
         if debug:
             # Write comparison data to file
