@@ -8,6 +8,7 @@ from click.core import Command, Context
 from rich.console import Console
 
 from piperider_cli import event
+from piperider_cli.error import PipeRiderError
 from piperider_cli.guide import Guide
 
 _enable_trackback: bool = os.environ.get('PIPERIDER_PRINT_TRACKBACK') == '1'
@@ -42,6 +43,10 @@ class TrackCommand(Command):
         else:
             console.print(f'[bold red]Error:[/bold red] {msg}')
 
+    def _show_hint_message(self, hint):
+        console = Console()
+        console.print(f'[bold yellow]Hint[/bold yellow]:\n  {hint}')
+
     def invoke(self, ctx: Context) -> t.Any:
         status = False
         try:
@@ -55,9 +60,12 @@ class TrackCommand(Command):
             if _enable_trackback:
                 print(traceback.format_exc())
             self._show_error_message(e, ctx.params)
+            if isinstance(e, PipeRiderError):
+                if e.hint:
+                    self._show_hint_message(e.hint)
             sentry_sdk.capture_exception(e)
             sentry_sdk.flush()
             sys.exit(1)
         finally:
-            event.log_event(ctx.command.name, ctx.params, status)
-            pass
+            event.log_usage_event(ctx.command.name, ctx.params, status)
+            event.flush_events(ctx.command.name)
