@@ -5,13 +5,14 @@ from datetime import datetime, date
 from typing import Union, List, Tuple
 
 from dateutil.relativedelta import relativedelta
-from sqlalchemy import MetaData, Table, Column, String, Integer, Numeric, Date, DateTime, Boolean, select, func, \
-    distinct, case
+from sqlalchemy import MetaData, Table, Column, String, Integer, Numeric, Date, DateTime, Boolean, ARRAY, select, func, \
+    distinct, case, text
+from sqlalchemy.engine import Engine, Connection
 from sqlalchemy.sql import FromClause
 from sqlalchemy.sql.elements import ColumnClause
 from sqlalchemy.sql.expression import CTE, false, true
 from sqlalchemy.types import Float
-from sqlalchemy.engine import Engine, Connection
+
 from .event import ProfilerEventHandler, DefaultProfilerEventHandler
 
 HISTOGRAM_NUM_BUCKET = 50
@@ -52,11 +53,11 @@ def format_float(val: Union[int, float]) -> str:
     elif base < 9:
         return f"{val / (10 ** 6):.1f}M"
     elif base < 12:
-        return f"{val / (10 ** 9):.1f}T"
+        return f"{val / (10 ** 9):.1f}B"
     elif base < 15:
-        return f"{val / (10 ** 12):.1f}B"
+        return f"{val / (10 ** 12):.1f}T"
     else:
-        return f"{val / (10 ** 12):.0f}B"
+        return f"{val / (10 ** 12):.0f}T"
 
 
 class Profiler:
@@ -122,9 +123,23 @@ class Profiler:
 
         return result
 
+    def _drop_unsupported_columns(self, table: Table):
+        array_columns = []
+        candidate_columns = []
+
+        for column in table.columns:
+            if isinstance(column.type, ARRAY):
+                array_columns.append(column.name + '.')
+            if any(column.name.startswith(bypass_column) for bypass_column in array_columns):
+                # Skip columns under an array
+                continue
+            candidate_columns.append(column)
+        return candidate_columns
+
     def _profile_table(self, table: Table) -> dict:
+        candidate_columns = self._drop_unsupported_columns(table)
         col_index = 0
-        col_count = len(table.columns)
+        col_count = len(candidate_columns)
         columns = {}
         result = {
             "name": table.name,
@@ -149,7 +164,7 @@ class Profiler:
         self.event_handler.handle_table_progress(result, col_count, col_index)
 
         # Profile columns
-        for column in table.columns:
+        for column in candidate_columns:
             columns[column.name] = self._profile_column(table, column)
             col_index = col_index + 1
             self.event_handler.handle_table_progress(result, col_count, col_index)
@@ -272,10 +287,9 @@ class BaseColumnProfiler:
             stmt = select([
                 func.count().label("_total"),
                 func.count(cte.c.c).label("_non_nulls"),
-                func.count(distinct(cte.c.c)).label("_distinct")
             ])
             result = conn.execute(stmt).fetchone()
-            _total, _non_nulls, _distinct = result
+            _total, _non_nulls, = result
 
             return {
                 'total': _total,
@@ -283,7 +297,6 @@ class BaseColumnProfiler:
                 'nulls': _total - _non_nulls,
                 'valids': _non_nulls,
                 'invalids': 0,
-                'distinct': _distinct,
                 'distribution': None,
             }
 
@@ -591,6 +604,12 @@ class NumericColumnProfiler(BaseColumnProfiler):
                     'p75': ntile(75),
                     'p95': ntile(95),
                 }
+        elif self._get_database_backend() == 'bigquery':
+            # BigQuery does not support WITHIN, change to use over
+            #   Ref: https://github.com/great-expectations/great_expectations/blob/develop/great_expectations/dataset/sqlalchemy_dataset.py#L1019:9
+            selects = [
+                func.percentile_disc(column, percentile).over() for percentile in [0.05, 0.25, 0.5, 0.75, 0.95]
+            ]
         else:
             # https://docs.sqlalchemy.org/en/14/core/functions.html#sqlalchemy.sql.functions.percentile_disc
             #
@@ -604,15 +623,16 @@ class NumericColumnProfiler(BaseColumnProfiler):
             selects = [
                 func.percentile_disc(percentile).within_group(column) for percentile in [0.05, 0.25, 0.5, 0.75, 0.95]
             ]
-            stmt = select(selects).select_from(table)
-            result = conn.execute(stmt).fetchone()
-            return {
-                'p5': dtof(result[0]),
-                'p25': dtof(result[1]),
-                'p50': dtof(result[2]),
-                'p75': dtof(result[3]),
-                'p95': dtof(result[4]),
-            }
+
+        stmt = select(selects).select_from(table)
+        result = conn.execute(stmt).fetchone()
+        return {
+            'p5': dtof(result[0]),
+            'p25': dtof(result[1]),
+            'p50': dtof(result[2]),
+            'p75': dtof(result[3]),
+            'p95': dtof(result[4]),
+        }
 
     def _profile_histogram(
         self,
@@ -826,6 +846,10 @@ class DatetimeColumnProfiler(BaseColumnProfiler):
                     return func.strftime("%Y-%m-01", args[1])
                 else:
                     return func.strftime("%Y-%m-%d", args[1])
+            elif self._get_database_backend() == 'bigquery':
+                date_expression = args[1]
+                date_part = args[0]
+                return func.date_trunc(date_expression, text(date_part))
             else:
                 return func.date_trunc(*args)
 
